==> dc-cudami-server-business-4.0.0-sources.jar: de/digitalcollections/cudami/server/business/impl/service/identifiable/entity/parts/EntityPartServiceImpl.java <==
package de.digitalcollections.cudami.server.business.impl.service.identifiable.entity.parts;

import de.digitalcollections.cudami.server.backend.api.repository.identifiable.entity.parts.EntityPartRepository;
import de.digitalcollections.cudami.server.business.api.service.identifiable.entity.parts.EntityPartService;
import de.digitalcollections.cudami.server.business.impl.service.identifiable.IdentifiableServiceImpl;
import de.digitalcollections.model.api.filter.Filtering;
import de.digitalcollections.model.api.identifiable.entity.Entity;
import de.digitalcollections.model.api.identifiable.entity.parts.EntityPart;
import de.digitalcollections.model.api.identifiable.resource.FileResource;
import java.time.LocalDate;
import java.util.List;
import java.util.UUID;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

@Service
public class EntityPartServiceImpl<P extends EntityPart, E extends Entity>
    extends IdentifiableServiceImpl<P> implements EntityPartService<P, E> {

  @Autowired
  public EntityPartServiceImpl(
      @Qualifier("entityPartRepositoryImpl") EntityPartRepository<P, E> repository) {
    super(repository);
  }

  @Override
  public void addRelatedEntity(P entityPart, E entity) {
    ((EntityPartRepository) repository).addRelatedEntity(entityPart, entity);
  }

  @Override
  public void addRelatedEntity(UUID entityPartUuid, UUID entityUuid) {
    ((EntityPartRepository) repository).addRelatedEntity(entityPartUuid, entityUuid);
  }

  @Override
  public void addRelatedFileresource(P entityPart, FileResource fileResource) {
    ((EntityPartRepository) repository).addRelatedFileresource(entityPart, fileResource);
  }

  @Override
  public void addRelatedFileresource(UUID entityPartUuid, UUID fileResourceUuid) {
    ((EntityPartRepository) repository).addRelatedFileresource(entityPartUuid, fileResourceUuid);
  }

  protected Filtering filteringForActive() {
    // business logic that defines, what "active" means
    LocalDate now = LocalDate.now();
    Filtering filtering =
        Filtering.defaultBuilder()
            .filter("publicationStart")
            .lessOrEqualAndSet(now)
            .filter("publicationEnd")
            .greaterOrNotSet(now)
            .build();
    return filtering;
  }

  @Override
  public List<E> getRelatedEntities(P entityPart) {
    return ((EntityPartRepository) repository).getRelatedEntities(entityPart);
  }

  @Override
  public List<E> getRelatedEntities(UUID entityPartUuid) {
    return ((EntityPartRepository) repository).getRelatedEntities(entityPartUuid);
  }

  @Override
  public List<FileResource> getRelatedFileResources(P entityPart) {
    return ((EntityPartRepository) repository).getRelatedFileResources(entityPart);
  }

  @Override
  public List<FileResource> getRelatedFileResources(UUID entityPartUuid) {
    return ((EntityPartRepository) repository).getRelatedFileResources(entityPartUuid);
  }

  @Override
  public List<E> saveRelatedEntities(P entityPart, List<E> entities) {
    return ((EntityPartRepository) repository).saveRelatedEntities(entityPart, entities);
  }

  @Override
  public List<E> saveRelatedEntities(UUID entityPartUuid, List<E> entities) {
    return ((EntityPartRepository) repository).saveRelatedEntities(entityPartUuid, entities);
  }

  @Override
  public List<FileResource> saveRelatedFileResources(
      P entityPart, List<FileResource> fileResources) {
    return ((EntityPartRepository) repository).saveRelatedFileResources(entityPart, fileResources);
  }

  @Override
  public List<FileResource> saveRelatedFileResources(
      UUID entityPartUuid, List<FileResource> fileResources) {
    return ((EntityPartRepository) repository)
        .saveRelatedFileResources(entityPartUuid, fileResources);
  }
}

==> dc-cudami-server-business-4.4.3-sources.jar: de/digitalcollections/cudami/server/business/impl/service/identifiable/entity/parts/EntityPartServiceImpl.java <==
package de.digitalcollections.cudami.server.business.impl.service.identifiable.entity.parts;

import de.digitalcollections.cudami.server.backend.api.repository.identifiable.entity.parts.EntityPartRepository;
import de.digitalcollections.cudami.server.business.api.service.identifiable.entity.parts.EntityPartService;
import de.digitalcollections.cudami.server.business.impl.service.identifiable.IdentifiableServiceImpl;
import de.digitalcollections.model.api.filter.Filtering;
import de.digitalcollections.model.api.identifiable.entity.Entity;
import de.digitalcollections.model.api.identifiable.entity.parts.EntityPart;
import de.digitalcollections.model.api.identifiable.resource.FileResource;
import java.time.LocalDate;
import java.util.List;
import java.util.UUID;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

@Service
public class EntityPartServiceImpl<P extends EntityPart> extends IdentifiableServiceImpl<P>
    implements EntityPartService<P> {

  @Autowired
  public EntityPartServiceImpl(
      @Qualifier("entityPartRepositoryImpl") EntityPartRepository<P> repository) {
    super(repository);
  }

  @Override
  public void addRelatedEntity(UUID entityPartUuid, UUID entityUuid) {
    ((EntityPartRepository<P>) repository).addRelatedEntity(entityPartUuid, entityUuid);
  }

  @Override
  public void addRelatedFileresource(UUID entityPartUuid, UUID fileResourceUuid) {
    ((EntityPartRepository<P>) repository).addRelatedFileresource(entityPartUuid, fileResourceUuid);
  }

  protected Filtering filteringForActive() {
    // business logic that defines, what "active" means
    LocalDate now = LocalDate.now();
    Filtering filtering =
        Filtering.defaultBuilder()
            .filter("publicationStart")
            .lessOrEqualAndSet(now)
            .filter("publicationEnd")
            .greaterOrNotSet(now)
            .build();
    return filtering;
  }

  @Override
  public List<Entity> getRelatedEntities(UUID entityPartUuid) {
    return ((EntityPartRepository<P>) repository).getRelatedEntities(entityPartUuid);
  }

  @Override
  public List<FileResource> getRelatedFileResources(UUID entityPartUuid) {
    return ((EntityPartRepository<P>) repository).getRelatedFileResources(entityPartUuid);
  }

  @Override
  public List<Entity> saveRelatedEntities(UUID entityPartUuid, List<Entity> entities) {
    return ((EntityPartRepository<P>) repository).saveRelatedEntities(entityPartUuid, entities);
  }

  @Override
  public List<FileResource> saveRelatedFileResources(
      UUID entityPartUuid, List<FileResource> fileResources) {
    return ((EntityPartRepository<P>) repository)
        .saveRelatedFileResources(entityPartUuid, fileResources);
  }
}
